StageState

Struct StageState 

pub struct StageState {
    pub stage_id: StageId,
    pub created_at_ms: i64,
    pub stage_plan: Arc<dyn ExecutionPlan>,
    pub assigned_partitions: HashSet<usize>,
    pub task_sets: Vec<TaskSet>,
    pub job_task_distribution: Arc<HashMap<TaskId, NodeId>>,
    pub job_meta: Arc<HashMap<String, String>>,
}
Tracks the runtime state of a single execution stage on the local node.

Fields

stage_id: StageIdcreated_at_ms: i64stage_plan: Arc<dyn ExecutionPlan>assigned_partitions: HashSet<usize>

Partitions assigned to this local node for execution.

task_sets: Vec<TaskSet>

Active and completed task groups for this stage on this node.

job_task_distribution: Arc<HashMap<TaskId, NodeId>>

Global mapping of every task in the job to its assigned node.

job_meta: Arc<HashMap<String, String>>

Implementations

Source

impl StageState

pub fn from_scheduled_tasks( scheduled_tasks: ScheduledTasks, ) -> DistResult<HashMap<StageId, StageState>>

pub fn num_running_tasks(&self) -> usize

pub fn num_pending_tasks(&self) -> usize

pub fn all_assigned_partitions_completed(&self) -> bool

Returns true if all tasks assigned to this stage on the local node have completed.

pub fn get_plan( &mut self, partition: usize, ) -> DistResult<(Uuid, Arc<dyn ExecutionPlan>)>

pub fn start_task( &mut self, partition: usize, task_set_id: Uuid, abort_handle: AbortHandle, ) -> DistResult<()>

pub fn complete_task( &mut self, task_id: TaskId, task_set_id: Uuid, task_metrics: TaskMetrics, )

pub fn never_executed(&self) -> bool

pub fn abort_running_tasks(&mut self)