pub struct ReceiverStreamBuilder<O> { /* private fields */ }Implementations
Sourceimpl<O: Send + 'static> ReceiverStreamBuilder<O>
impl<O: Send + 'static> ReceiverStreamBuilder<O>
Sourcepub fn tx(&self) -> Sender<DistResult<O>>
pub fn tx(&self) -> Sender<DistResult<O>>
Get a handle for sending data to the output
Sourcepub fn spawn_on<F>(&mut self, task: F, handle: &Handle)
pub fn spawn_on<F>(&mut self, task: F, handle: &Handle)
Same as [Self::spawn] but it spawns the task on the provided runtime
Sourcepub fn build(self) -> BoxStream<'static, DistResult<O>>
pub fn build(self) -> BoxStream<'static, DistResult<O>>
Create a stream of all data written to tx